==> auto-depends-1.6.12-sources.jar: org/jvnet/hk2/component/TypeLiteralBasedBinder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.component;

import com.sun.hk2.component.ConstructorCreator;
import com.sun.hk2.component.InhabitantsFile;
import org.glassfish.hk2.TypeLiteral;

import java.util.StringTokenizer;

/**
 * Binder for a {@link TypeLiteral} binding
 *
 * @author Jerome Dochez
 */
class TypeLiteralBasedBinder<T> extends AbstractResolvedBinder<T> {

    final TypeLiteral<T> typeLiteral;

    TypeLiteralBasedBinder(BinderImpl<? super T> metadata, TypeLiteral<T> typeLiteral) {
        super(metadata);
        this.typeLiteral = typeLiteral;
    }

    @Override
    void registerIn(Habitat habitat) {
        MultiMap<String, String> inhMetadata = super.populateMetadata();
        final String parameterizedTypes = BinderFactoryImpl.exploreType(typeLiteral);
        if (parameterizedTypes.contains("<")) {
            String commaSeparatedTypes = parameterizedTypes.substring(parameterizedTypes.indexOf('<')+1, parameterizedTypes.length()-1);
            StringTokenizer st = new StringTokenizer(commaSeparatedTypes, ",");
            while(st.hasMoreTokens()) {
                inhMetadata.add(InhabitantsFile.PARAMETERIZED_TYPE, st.nextToken());
            }
        }

        super.registerIn(habitat, com.sun.hk2.component.Inhabitants.wrapByScope(
                new ConstructorCreator<T>(typeLiteral.getRawType(), habitat, inhMetadata) {
                    @Override
                    public String typeName(){
                        return parameterizedTypes;
                    }
                },
                habitat,
                metadata.scope));
    }
}

==> auto-depends-1.6.33-sources.jar: org/jvnet/hk2/component/TypeLiteralBasedBinder.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.component;

import com.sun.hk2.component.ConstructorCreator;
import com.sun.hk2.component.InhabitantsFile;
import org.glassfish.hk2.TypeLiteral;

import java.util.StringTokenizer;

/**
 * Binder for a {@link TypeLiteral} binding
 *
 * @author Jerome Dochez
 */
class TypeLiteralBasedBinder<T> extends AbstractResolvedBinder<T> {

    final TypeLiteral<T> typeLiteral;

    TypeLiteralBasedBinder(BinderImpl<? super T> metadata, TypeLiteral<T> typeLiteral) {
        super(metadata);
        this.typeLiteral = typeLiteral;
    }

    @Override
    Inhabitant<?> registerIn(Habitat habitat) {
        MultiMap<String, String> inhMetadata = super.populateMetadata();
        final String parameterizedTypes = BinderFactoryImpl.exploreType(typeLiteral);
        if (parameterizedTypes.contains("<")) {
            String commaSeparatedTypes = parameterizedTypes.substring(parameterizedTypes.indexOf('<')+1, parameterizedTypes.length()-1);
            StringTokenizer st = new StringTokenizer(commaSeparatedTypes, ",");
            while(st.hasMoreTokens()) {
                inhMetadata.add(InhabitantsFile.PARAMETERIZED_TYPE, st.nextToken());
            }
        }

        Inhabitant<T> inhabitant = com.sun.hk2.component.Inhabitants.wrapByScope(
                new ConstructorCreator<T>(typeLiteral.getRawType(), habitat, inhMetadata) {
                    @Override
                    public String typeName(){
                        return parameterizedTypes;
                    }
                },
                habitat,
                metadata.scope);
        super.registerIn(habitat, inhabitant);
        return inhabitant;
    }
}
